==> quanyi-goods-service-api-0.0.12-merge-20240118.055300-3-sources.jar: cn/com/duiba/quanyi/goods/service/api/dto/goods/SpuDto.java <==
package cn.com.duiba.quanyi.goods.service.api.dto.goods;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * SPU表
 *
 * @author kjj mybatis generator
 * @date 2023-11-20
 */
@Data
public class SpuDto implements Serializable {

    private static final long serialVersionUID = 17004797934064068L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 供应商id
     */
    private Long supplierId;

    /**
     * 产品编码
     */
    private String productCode;

    /**
     * 面值
     */
    private Integer amount;

    /**
     * 商品名称
     */
    private String spuName;

    /**
     * 商品类型，1-实物，2-微信立减金
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     */
    private Integer spuType;

    /**
     * 商品主图链接，多张图用英文 逗号 分割
     */
    private String mainImgs;

    /**
     * 商品详情图链接，多张图用英文 逗号 分割
     */
    private String detailImgs;

    /**
     * 商品描述
     */
    private String spuDesc;

    /**
     * 最低供货价，单位分，比如1元，数据存为100
     */
    private Integer minSupplyPrice;

    /**
     * 最高供货价，单位分，比如1元，数据存为100
     */
    private Integer maxSupplyPrice;

    /**
     * 最低指导价，单位分，比如1元，数据存为100
     */
    private Integer minMarketPrice;

    /**
     * 最高指导价，单位分，比如1元，数据存为100
     */
    private Integer maxMarketPrice;

    /**
     * 最低建议售价，单位分，比如1元，数据存为100
     */
    private Integer minSellPrice;

    /**
     * 最高建议售价，单位分，比如1元，数据存为100
     */
    private Integer maxSellPrice;

    /**
     * 商品状态：0-停用，1-启用
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuStatusEnum
     */
    private Integer spuStatus;

    /**
     * 商品备注
     */
    private String spuRemark;

    /**
     * 创建人ID
     */
    private Long createOperatorId;

    /**
     * 创建人姓名
     */
    private String createOperatorName;

    /**
     * 是否已删除：0-未删除，1-已删除
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.LogicDeleteEnum
     */
    private Integer logicDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;
}

==> quanyi-goods-service-api-0.0.85-merge-20240820.022335-23-sources.jar: cn/com/duiba/quanyi/goods/service/api/dto/goods/SpuDto.java <==
package cn.com.duiba.quanyi.goods.service.api.dto.goods;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * SPU表
 *
 * @author kjj mybatis generator
 * @date 2023-11-20
 */
@Data
public class SpuDto implements Serializable {

    private static final long serialVersionUID = 17004797934064068L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 供应商id
     */
    private Long supplierId;

    /**
     * 商品名称
     */
    private String spuName;

    /**
     * 商品类型，1-实物，2-微信立减金
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     */
    private Integer spuType;

    /**
     * 商品主图链接，多张图用英文 逗号 分割
     */
    private String mainImgs;

    /**
     * 商品详情图链接，多张图用英文 逗号 分割
     */
    private String detailImgs;

    /**
     * 商品描述
     */
    private String spuDesc;

    /**
     * 最低供货价，单位分，比如1元，数据存为100
     */
    private Integer minSupplyPrice;

    /**
     * 最高供货价，单位分，比如1元，数据存为100
     */
    private Integer maxSupplyPrice;

    /**
     * 最低指导价，单位分，比如1元，数据存为100
     */
    private Integer minMarketPrice;

    /**
     * 最高指导价，单位分，比如1元，数据存为100
     */
    private Integer maxMarketPrice;

    /**
     * 最低建议售价，单位分，比如1元，数据存为100
     */
    private Integer minSellPrice;

    /**
     * 最高建议售价，单位分，比如1元，数据存为100
     */
    private Integer maxSellPrice;

    /**
     * 商品状态：0-停用，1-启用
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuStatusEnum
     */
    private Integer spuStatus;

    /**
     * 商品备注
     */
    private String spuRemark;

    /**
     * 商品规格
     */
    private List<AttrDto> attrList;

    /**
     * 创建人ID
     */
    private Long createOperatorId;

    /**
     * 创建人姓名
     */
    private String createOperatorName;

    /**
     * 是否已删除：0-未删除，1-已删除
     *
     * @see cn.com.duiba.quanyi.goods.service.api.enums.LogicDeleteEnum
     */
    private Integer logicDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;
}
